@@ -1,6 +1,6 @@
 from fabric import state
 from fabric.main import get_hosts
-from fabric.network import interpret_host_string, HostConnectionCache
+from fabric.network import interpret_host_string
 
 class FabricAbortException(Exception):
     pass
@@ -8,9 +8,6 @@ class FabricAbortException(Exception):
 def fab(command, *args, **kwargs):
     """ Runs fab command. Accepts callable. """
 
-    # clean the connection cache
-    state.connections = HostConnectionCache()
-
     # collect results
     results = []
 
@@ -29,3 +26,9 @@ def fab(command, *args, **kwargs):
         traceback.print_exc()
         raise FabricAbortException()
 
+def close_fabric_connections():
+    for key, connection in state.connections.items():
+        connection.close()
+        del state.connections[key]
+
+
